==> libpolyxmass_0.8.7.orig.tar.gz: libpolyxmass-0.8.7/src/libpolyxmass.h <==

/* GNU polyxmass, the massists' program
 * Header file for all the files in the libpolyxmass library.
 *
 * Copyright 2002,2003, 2004 (C) Filippo Rusconi
 * Licensed under the GNU General Public Licence (GPL)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef LIBPOLYXMASS_H
#define LIBPOLYXMASS_H




#include <libpolyxmass/libpolyxmass-acidobasic.h>
#include <libpolyxmass/libpolyxmass-atomspec.h>
#include <libpolyxmass/libpolyxmass-chemgroup.h>
#include <libpolyxmass/libpolyxmass-config.h>
#include <libpolyxmass/libpolyxmass-globals.h>
#include <libpolyxmass/libpolyxmass-init.h>
#include <libpolyxmass/libpolyxmass-masspair.h>
#include <libpolyxmass/libpolyxmass-modifspec.h>
#include <libpolyxmass/libpolyxmass-monomerspec.h>
#include <libpolyxmass/libpolyxmass-note.h>
#include <libpolyxmass/libpolyxmass-polchemdefspec.h>
#include <libpolyxmass/libpolyxmass-prop.h>
#include <libpolyxmass/libpolyxmass-userspec.h>
#include <libpolyxmass/pxmchem-atom.h>
#include <libpolyxmass/pxmchem-calcopt.h>
#include <libpolyxmass/pxmchem-cleave.h>
#include <libpolyxmass/pxmchem-cleaveopt.h>
#include <libpolyxmass/pxmchem-cleavespec.h>
#include <libpolyxmass/pxmchem-elemcompcalc.h>
#include <libpolyxmass/pxmchem-findmass.h>
#include <libpolyxmass/pxmchem-findmassopt.h>
#include <libpolyxmass/pxmchem-formula.h>
#include <libpolyxmass/pxmchem-fragment.h>
#include <libpolyxmass/pxmchem-fragopt.h>
#include <libpolyxmass/pxmchem-fragspec.h>
#include <libpolyxmass/pxmchem-ionizerule.h>
#include <libpolyxmass/pxmchem-masscalc.h>
#include <libpolyxmass/pxmchem-mnmcompcalc.h>
#include <libpolyxmass/pxmchem-modif.h>
#include <libpolyxmass/pxmchem-monomer.h>
#include <libpolyxmass/pxmchem-oligomer.h>
#include <libpolyxmass/pxmchem-plugin.h>
#include <libpolyxmass/pxmchem-polchemdef.h>
#include <libpolyxmass/pxmchem-polchemdef-plugins.h>
#include <libpolyxmass/pxmchem-polymer.h>
#include <libpolyxmass/pxmchem-polymer-plugins.h>
#include <libpolyxmass/pxmchem-searchmass.h>
#include <libpolyxmass/pxmchem-searchmassopt.h>




#endif /* LIBPOLYXMASS_H */

==> libpolyxmass_0.8.9.orig.tar.gz: libpolyxmass-0.8.9/src/libpolyxmass.h <==

/* GNU polyxmass, the massists' program
 * Header file for all the files in the libpolyxmass library.
 *
 * Copyright 2002,2003, 2004 (C) Filippo Rusconi
 * Licensed under the GNU General Public Licence (GPL)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef LIBPOLYXMASS_H
#define LIBPOLYXMASS_H




#include <libpolyxmass/libpolyxmass-acidobasic.h>
#include <libpolyxmass/libpolyxmass-atomspec.h>
#include <libpolyxmass/libpolyxmass-chemgroup.h>
#include <libpolyxmass/libpolyxmass-config.h>
#include <libpolyxmass/libpolyxmass-globals.h>
#include <libpolyxmass/libpolyxmass-init.h>
#include <libpolyxmass/libpolyxmass-masspair.h>
#include <libpolyxmass/libpolyxmass-modifspec.h>
#include <libpolyxmass/libpolyxmass-monomerspec.h>
#include <libpolyxmass/libpolyxmass-note.h>
#include <libpolyxmass/libpolyxmass-plugin.h>
#include <libpolyxmass/libpolyxmass-polchemdefspec.h>
#include <libpolyxmass/libpolyxmass-prop.h>
#include <libpolyxmass/libpolyxmass-reportopt.h>
#include <libpolyxmass/libpolyxmass-userspec.h>
#include <libpolyxmass/pxmchem-atom.h>
#include <libpolyxmass/pxmchem-calcopt.h>
#include <libpolyxmass/pxmchem-cleave.h>
#include <libpolyxmass/pxmchem-cleaveopt.h>
#include <libpolyxmass/pxmchem-cleavespec.h>
#include <libpolyxmass/pxmchem-elemcompcalc.h>
#include <libpolyxmass/pxmchem-findmass.h>
#include <libpolyxmass/pxmchem-findmassopt.h>
#include <libpolyxmass/pxmchem-formula.h>
#include <libpolyxmass/pxmchem-fragment.h>
#include <libpolyxmass/pxmchem-fragopt.h>
#include <libpolyxmass/pxmchem-fragspec.h>
#include <libpolyxmass/pxmchem-ionizerule.h>
#include <libpolyxmass/pxmchem-masscalc.h>
#include <libpolyxmass/pxmchem-mnmcompcalc.h>
#include <libpolyxmass/pxmchem-modif.h>
#include <libpolyxmass/pxmchem-monomer.h>
#include <libpolyxmass/pxmchem-oligomer.h>
#include <libpolyxmass/pxmchem-polchemdef.h>
#include <libpolyxmass/pxmchem-polchemdef-plugins.h>
#include <libpolyxmass/pxmchem-polymer.h>
#include <libpolyxmass/pxmchem-polymer-plugins.h>
#include <libpolyxmass/pxmchem-searchmass.h>
#include <libpolyxmass/pxmchem-searchmassopt.h>




#endif /* LIBPOLYXMASS_H */
